@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: MessageBatch.pm 5048 2010-08-03 11:19:15Z sysjkf $
+#   $Id: MessageBatch.pm 5115 2012-11-10 13:11:25Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ use DBI qw(:sql_types);
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 5048 $, 10;
+$VERSION = substr q$Revision: 5115 $, 10;
 
 my $maxcleanbytes    = 0;
 my $maxcleanmessages = 0;
@@ -1253,10 +1253,12 @@ sub CreateEicarBatch {
   my($fh, $temporaryname);
   ($fh, $temporaryname) = tempfile()
     or die "Could not create temp file $temporaryname for test message, $!";
-  print $fh <<EOFLint;
-WDVPIVAlQEFQWzRcUFpYNTQoUF4pN0NDKTd9JEVJQ0FSLVNUQU5EQVJELUFOVElWSVJVUy1URVNU
-LUZJTEUhJEgrSCo=
-EOFLint
+  # This is a Base64-encoded, then ROT13-encoded copy of the EICAR test string.
+  # Had to ROT13 it, otherwise new clamd detects it and quarantines this file.
+  my $eicarstring = "JQICVINyDRSDJmEpHScLAGDbHS4cA0AQXGq9WRIWD0SFYIAHDH5RDIWRYHSBIRyJFIWIHl1HEIAH\nYHMWGRHuWRteFPb=\n";
+  $eicarstring =~ tr[a-zA-Z][n-za-mN-ZA-M]; # Undo ROT13 encoding
+  print $fh $eicarstring;
+
   $fh->close();
   $newmessage->{store}->{dpath} = $temporaryname;
 
